@@ -2,6 +2,7 @@
 /* ѹ                                                                   */
 /*----------------------------------------------------------------------------*/
 /* 1.0 : APIб(2003/06)                                             */
+/* 1.1 : -S10ʸޤǻǽˤ                                         */
 /*============================================================================*/
   
 #include <musashi.h>
@@ -20,10 +21,10 @@
 #include <xml2xtHelp.h>
 struct mssComHelp comHelp={
   "xml2xt",       /* ޥ̾       */
-  "1.0",          /* С       */
+  "1.1",          /* С       */
   HELPT,          /* ޥɥȥ */                                    
   HELPS,          /*              */
-  HELPE,          /*              */
+  HELPE,          /*            */
   HELPR,          /* ȥޥ     */
   HELPA,          /* Ծ         */
   HELPB,          /* ХݡȾ */
@@ -131,8 +132,8 @@ static struct XmlFld *fld;
     "S",    /* (ʣʸԲ)                                   */
     0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
     "_",    /* ǥե                                                   */
-    1,      /* ʸκǾĹ                                               */
-    1,      /* ʸκĹ                                               */
+    0,      /* ʸκǾĹ                                               */
+    10,     /* ʸκĹ                                               */
     SPCT,   /* ΥץΥȥ(Helpɽ)                         */
     SPCC    /* ΥץΥ(Helpɽ)                         */
   };
@@ -360,47 +361,73 @@ static void writeEncStr(char *str){
 }
 
 /*ΥڡʤΥڡʸѴ*/
-/*ʸ֤ѤΤfreeϤǤʤΤ*/
 static char *chgSpc(char *str){
-  int len;
+  int repStrLen;
+  int cnt;
   char *pos;
+  char *last;
+  char *newStr; /*ڡѴ¸ʸΰ*/
+  char *retStr; /*Ѥʸ*/
 
   if(str==NULL) return(NULL);
 
-  /*Υڡʸʤ*/
+  newStr=mssMalloc(sizeof(char)*(MssFieldMaxLen+1),"chgSpc");
+  *newStr='\0';
+
+  repStrLen=strlen(optSPC.str);
+
+  /*Υڡʸ򥹥å*/
   while(*str!='\0'){
     if(!isspace(*str)) break;
     str++;
   }
-  len=strlen(str);
-  if(len<=0) return(NULL);
 
   /*Υڡʸʤ*/
-  pos=str+strlen(str)-1;
-  while(1){
-    if(!isspace(*pos)) break;
-    *pos='\0';
-    pos--;
+  last=str+strlen(str)-1;
+  if(str==last+1) return(newStr);
+  while(*last==' '){
+    if(!isspace(*last)) break;
+    *last--='\0';
   }
 
-  /*ڡѴ*/
-  pos=str;
-  while(*pos!='\0'){
-    if( isspace(*pos) ) *pos=*optSPC.str;
-    pos++;
+  cnt=0;
+  pos=newStr;
+  while(*str!='\0'){
+    if(*str==' '){
+      /*ܺĹĶ餽Ǥڤ*/
+      if(cnt+repStrLen>=MssFieldMaxLen-1){
+        break;
+      }
+      strncpy(pos,optSPC.str,repStrLen);
+      pos+=repStrLen;
+      str++;
+      cnt+=repStrLen;
+    }else{
+      *pos++=*str++;
+      cnt++;
+    }
   }
-  return(str);
+  *pos='\0';
+
+  retStr=mssStrdup(newStr);
+  mssFree(newStr);
+  return(retStr);
 }
  
 /*fldDat*/
 static void printDat(XmlState *state){
   int fn;
+  char *str;
 
   for(fn=0; fn<fld->cnt-1; fn++){
-    writeEncStr(chgSpc(fldDat[fn]));
+    str=chgSpc(fldDat[fn]);
+    writeEncStr(str);
+    mssFree(str);
     mssWriteDlm(fpw);
   }
-    writeEncStr(chgSpc(fldDat[fn]));
+    str=chgSpc(fldDat[fn]);
+    writeEncStr(str);
+    mssFree(str);
     mssWriteRet(fpw);
   mssGV.outCnt++;
 }
@@ -758,7 +785,7 @@ int main(int argc, char *argv[]){
   tmp=optSPC.str;
   while(*tmp!='\0'){
     if(isspace(*tmp++)) {
-      mssShowErrMsg("can't use space character in -s option");
+      mssShowErrMsg("cannot use space character in -S option");
       mssEnd(mssErrorNoDefault);
     }
   }
