@@ -2,6 +2,7 @@
 /* ѹ                                                                   */
 /*----------------------------------------------------------------------------*/
 /* 1.0 : APIб 2003/06/20                                           */
+/* 1.1 : ͤǥȤĥǡưԶн(API) 2003/08/07     */
 /*============================================================================*/
 
 #include <musashi.h>
@@ -10,10 +11,10 @@
 #include <xtjoinHelp.h>
 struct mssComHelp comHelp={
   "xtjoin",       /* ޥ̾       */
-  "1.0",          /* С       */
+  "1.1",          /* С       */
   HELPT,          /* ޥɥȥ */ 
   HELPS,          /*              */
-  HELPE,          /*              */
+  HELPE,          /*            */
   HELPR,          /* ȥޥ     */
   HELPA,          /* Ծ         */
   HELPB,          /* ХݡȾ */
@@ -450,8 +451,8 @@ int main(int argc, char *argv[]){
   mssFree(fi);
 
   /*פη*/
-  if(sortedT){
-    if(sortedM){
+  if(sortedT==1){
+    if(sortedM==1){
       if(mstIsSmall) procType=5;
       else           procType=5;
     }else{
@@ -459,7 +460,7 @@ int main(int argc, char *argv[]){
       else           procType=4;
     }
   }else{
-    if(sortedM){
+    if(sortedM==1){
       if(mstIsSmall) procType=1;
       else           procType=3;
     }else{
@@ -548,10 +549,10 @@ int main(int argc, char *argv[]){
 
     frdT=mssInitFRD(fcT);
     frM =mssInitFldRec(fcM);
-    if(!sortedT){
+    if(sortedT!=1){
       fprT=mssReopenFPRsort(fprT,4,sfT,hdT->flds->cnt,optTMP.str);
     }
-    if(!sortedM){
+    if(sortedM!=1){
       fprM=mssReopenFPRsort(fprM,4,sfM,hdM->flds->cnt,optTMP.str);
     }
 
