@@ -2,6 +2,7 @@
 /* ѹ                                                                   */
 /*----------------------------------------------------------------------------*/
 /* 0.1 : ǿ 2003/06/20                                              */
+/* 0.2 : -cץɲ 2003/08/09                                          */
 /*============================================================================*/
 
 #include <musashi.h>
@@ -11,10 +12,10 @@
 #include <xtformatHelp.h>
 struct mssComHelp comHelp={
   "xtformat",     /* ޥ̾       */
-  "0.1",          /* С       */
+  "0.2",          /* С       */
   HELPT,          /* ޥɥȥ */
   HELPS,          /*              */
-  HELPE,          /*              */
+  HELPE,          /*            */
   HELPR,          /* ȥޥ     */
   HELPA,          /* Ծ         */
   HELPB,          /* ХݡȾ */
@@ -22,6 +23,10 @@ struct mssComHelp comHelp={
 };
 
 extern struct mssGlobalVariables mssGV;
+char *RepTarget; /*ִоʸ*/
+int RepTargetLen;
+char *RepStr;    /*ִʸ*/
+int RepStrLen;
 
 struct PrefixNode {
   char chr;                 /*Ρɤˤʸ*/
@@ -183,12 +188,39 @@ void freeBlock(struct Block *block){
   }
 }
 
+/*----------------------------------------------------------------------------*/
+/* strִ(optREP)˽ִִʸ֤                    */
+/*----------------------------------------------------------------------------*/
+char *replaceStr(char *str){
+  char *pos;
+  char *newStr;
+  char *c;
+  int len;
+
+  /*ʬΰ(ܺĹ*ִʸĹ(10)*/
+  newStr=mssMalloc(MssFieldMaxLen*11,"repStr");
+
+  c=newStr;
+  while( NULL != (pos=strstr(str,RepTarget)) ){
+    strncpy(c,str,pos-str);
+    c+=(pos-str);
+    strncpy(c,RepStr,RepStrLen);
+    c+=RepStrLen;
+    str=pos+RepTargetLen;
+  }
+  len=strlen(str);
+  strncpy(c,str,len);
+  c+=len;
+  *c='\0';
+  return(newStr);
+}
 
 /*----------------------------------------------------------------------------*/
 /* TXTNodeν                                                              */
 /*----------------------------------------------------------------------------*/
 void outTXT(struct PrefixNode *pt,char **fr,char *str,struct mssFPW *fpw){
   struct PrefixNode *pn;
+  char *repStr;
   int mcnt;
   int i;
   pn=pt;
@@ -212,7 +244,17 @@ void outTXT(struct PrefixNode *pt,char **fr,char *str,struct mssFPW *fpw){
     /*ߤprefixĥ꡼nodefldNo¸ߤȤȤ
       ޥåȤȤǡִʸ*/
     }else if(pn->fldNo!=-1){
-      mssWriteStr(*(fr+pn->fldNo),fpw);
+
+      /*ִ郎ꤵƤʤ*/
+      if(RepTarget==NULL){
+        mssWriteStr(*(fr+pn->fldNo),fpw);
+
+      /*ִ郎ꤵƤ*/
+      }else{
+        repStr=replaceStr(*(fr+pn->fldNo));
+        mssWriteStr(repStr,fpw);
+        mssFree(repStr);
+      }
       pn=pt;
       mcnt=0;
 
@@ -263,8 +305,6 @@ struct DocNode *outNode(
         }
       }
 
-
-
       /*郎פTHENΡɤ*/
       /*˵äƤϡƤ褦currentNoꤷƤ*/
       if(sel){
@@ -855,6 +895,22 @@ int main(int argc, char *argv[]){
             /* 2:ƤιԤƱͤȤư)                            */
   };
 
+/*----------------------------------------------------------------------------*/
+/* ʸִꥹ                                                           */
+/*----------------------------------------------------------------------------*/
+  MssOptSLS optREP={
+    OSLS,   /* ץ󥿥                                             */
+    "c",    /* (ʣʸԲ)                                   */
+    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
+    NULL,   /* ǥե(ʸ)                                           */
+    1,      /* ޤǶڤǿκ                             */
+    1,      /* ǤʸĹκǾ                                     */
+    MssFieldMaxLen,/* ǤʸĹκ                              */
+    1,      /* 1:Ǥ˥Ǥ,0:Բ  ex) aaaa:xxxxx            */
+    REPT,   /* ΥץΥȥ(Helpɽ)                         */
+    REPC    /* ΥץΥ(Helpɽ)                         */
+  };
+
 /*----------------------------------------------------------------------------*/
 /* ϥե                                                               */
 /*----------------------------------------------------------------------------*/
@@ -906,7 +962,7 @@ int main(int argc, char *argv[]){
 /*----------------------------------------------------------------------------*/
 /* ץޤȤ                                                       */
 /*----------------------------------------------------------------------------*/
-  void *opt[]={&optINF,&optREF,&optOTF,&optZIP,NULL};
+  void *opt[]={&optREP,&optINF,&optREF,&optOTF,&optZIP,NULL};
 
   struct mssHeader *hdi; /*ϥե<head>Ǽ¤*/
   struct mssFPR    *fpr; /*ϥե빽¤*/
@@ -933,6 +989,18 @@ int main(int argc, char *argv[]){
   fpr=mssOpenFPR(optINF.str,4);      /* ϥե륪ץ                  */
   hdi=mssReadHeader(fpr);            /* إåɤ߹                      */
 
+  if(optREP.set){
+     RepTarget=*optREP.strList;
+     RepTargetLen=strlen(*optREP.strList);
+  }else{
+     RepTarget=NULL;
+  }
+  if(optREP.set){
+     RepStr=*optREP.colList;
+     RepStrLen=strlen(*optREP.colList);
+  }else{
+     RepStr=NULL;
+  }
 
 /*----------------------------------------------------------------------------*/
 /* ̾ѿ̾ȤprefixTree˥å                                     */
