@@ -829,17 +829,35 @@ int mssIsValidStr(char *str)
 /**
  * # FUNCTION #
  * ޥɥ饤񤭽Ф
+ * argv˲ԤޤޤƤХڡѴƽϤ
  */
 static void printCmdLine(struct mssFPW *fp)
 {
-  int i;
+  int i,j,len;
+  char *str;
+
+
   mssWriteStr("\"",fp);
-  for(i=0; i<mssGV.argc-1; i++){
-    mssWriteStr(*(mssGV.argv+i),fp);
-    mssWriteStr(" ",fp);
+  for(i=0; i<mssGV.argc; i++){
+    len=strlen(*(mssGV.argv+i));
+    str=mssMalloc(sizeof(char)*(len+1),"printCmdLine");
+    for(j=0; j<len; j++){
+      if('\n'!=*(*(mssGV.argv+i)+j)){
+        *(str+j)=*(*(mssGV.argv+i)+j);
+      }else{
+        *(str+j)=' ';
+      }
+    }
+    *(str+j)='\0';
+    mssWriteStr(str,fp);
+    mssFree(str);
+
+    if(i!=mssGV.argc-1){
+      mssWriteStr(" ",fp);
+    }else{
+      mssWriteStr("\"",fp);
+    }
   }
-  mssWriteStr(*(mssGV.argv+i),fp); 
-  mssWriteStr("\"",fp);
 } 
 
 /**
