@@ -579,6 +579,65 @@ static MssValue cal_sum(struct mssCal *cal)
   return(v);
 }
 
+/**
+ * # FUNCTION #
+ * minؿ
+ * Ϳ: min(1,2,...,n)
+ * 1nǺǾ֤ͤ
+ * ˰ĤǤNULLͤȡNULL֤ͤ
+ * minؿǤϡ̾λ˥磻ɥɤѤǤ롣
+ */
+static MssValue cal_min(struct mssCal *cal)
+{
+  MssValue v;
+  int i,j;
+  mssVinit(&v,DBL);
+
+  mssVclearMax(&v);
+  for(i=0; i<cal->argCnt; i++){
+    for(j=0; j<cal->arg[i].valCnt; j++){
+      if(cal->arg[i].val[j].nul){
+        MssVnull(v); return(v);
+      }else{
+        if(v.v.d > cal->arg[i].val[j].v.d){
+          v.v.d = cal->arg[i].val[j].v.d;
+        }
+      }
+    }
+  }
+  return(v);
+}
+
+/**
+ * # FUNCTION #
+ * maxؿ
+ * Ϳ: max(1,2,...,n)
+ * 1nǺǾ֤ͤ
+ * ˰ĤǤNULLͤȡNULL֤ͤ
+ * maxnؿǤϡ̾λ˥磻ɥɤѤǤ롣
+ */
+static MssValue cal_max(struct mssCal *cal)
+{
+  MssValue v;
+  int i,j;
+  mssVinit(&v,DBL);
+
+  mssVclearMin(&v);
+  for(i=0; i<cal->argCnt; i++){
+    for(j=0; j<cal->arg[i].valCnt; j++){
+      if(cal->arg[i].val[j].nul){
+        MssVnull(v); return(v);
+      }else{
+        if(v.v.d < cal->arg[i].val[j].v.d){
+          v.v.d = cal->arg[i].val[j].v.d;
+        }
+      }
+    }
+  }
+  return(v);
+}
+
+
 /**
  * # FUNCTION #
  * logؿ
@@ -1467,8 +1526,8 @@ static MssValue cal_round(struct mssCal *cal)
 
   v0=cal->arg[0].val[0].v.d;
   v1=cal->arg[1].val[0].v.d;
-  if(v0<0) modf((v0-(v1/2)+DBL0)/v1,&vint);
-  else     modf((v0+(v1/2)-DBL0)/v1,&vint);
+  if(v0<0) modf((v0-(v1/2)-DBL0)/v1,&vint);
+  else     modf((v0+(v1/2)+DBL0)/v1,&vint);
   v.v.d=vint*v1;
 
   return(v);
@@ -2706,6 +2765,8 @@ struct Func func[]={
   {"leapyear"   ,0, 1,{S,E}    ,N   ,7 ,cal_leapyear},
 
   {"sum"        ,0, 1,{N,M,E}  ,N   ,7 ,cal_sum},
+  {"min"        ,0, 1,{N,M,E}  ,N   ,7 ,cal_min},
+  {"max"        ,0, 1,{N,M,E}  ,N   ,7 ,cal_max},
   {"sqrt"       ,0, 1,{N,E}    ,N   ,7 ,cal_Sqrt},
   {"power"      ,0, 1,{N,N,E}  ,N   ,7 ,cal_power},
   {"abs"        ,0, 1,{N,E}    ,N   ,7 ,cal_abs},
@@ -2913,7 +2974,7 @@ static struct Func *cal_setFuncAdd(char *str)
  *   1) ̤бط(̤ο)
  *
  * ϡʲΤȤꡣ
- *   1) ɬפʥڡν
+ *   1) ɬפʥڡ⤷ϲԤν
  * 
  */
 static char *cal_chkCal(char *str)
@@ -2943,8 +3004,10 @@ static char *cal_chkCal(char *str)
       *buf=*str;
        buf++; str++;
       while(*str!='"' && *str!='\0'){
-        *buf=*str;
-        buf++; str++;
+        if(*str!='\n'){
+          *buf=*str;
+          buf++; str++;
+        }
       }
       if(*str=='\0') {
         mssShowErrMsg("mismatch of \"\"");
@@ -2957,8 +3020,10 @@ static char *cal_chkCal(char *str)
       *buf=*str; buf++; str++;
       *buf=*str; buf++; str++;
       while(*str!=')' && *str!='\0'){
-        *buf=*str;
-        buf++; str++;
+        if(*str!='\n'){
+          *buf=*str;
+          buf++; str++;
+        }
       }
       if(*str=='\0') {
         mssShowErrMsg("mismatch of '(' and ')'");
@@ -2966,8 +3031,8 @@ static char *cal_chkCal(char *str)
       }
     }
 
-    /*ڡϵͤ*/
-    if(*str!=' '){
+    /*ڡ⤷ϲԤϵͤ*/
+    if(*str!=' ' && *str!='\n'){
       *buf=*str;
        buf++;
     }
