@@ -2,6 +2,7 @@
  * # CHAPTER #
  * ============================================================================
  * XMLtableΥإå򰷤ؿ
+ * 2002/08/07 mssSetOptKey: numFlg,revFlg򥯥ꥢɲ
  * ============================================================================
  */
 
@@ -525,7 +526,7 @@ void mssSetFieldsSort(struct mssFields *flds, struct mssFields *sortFlds)
 
   for(i=0; i<sortFlds->cnt; i++){
     no = MssFlds2num(sortFlds,i);
-    MssFlds2priority(flds,no)= i+1; //MssFlds2priority(sortFlds,i);
+    MssFlds2priority(flds,no)= i+1;
     MssFlds2revFlg(flds,no)  = MssFlds2revFlg(sortFlds,i);
     MssFlds2numFlg(flds,no)  = MssFlds2numFlg(sortFlds,i);
   }
@@ -1240,6 +1241,8 @@ void mssShowHeader(struct mssHeader *hd)
  * # FUNCTION #
  * mssFields¤Τ˳ǼƤ륽ȾheaderΥȾӤ
  * mssFieldsΥȾ󤫤鸫ưפƤХȺѤȤߤʤ
+ * numeric,reverseʤǡȤ̤ͥפƤ1֤
+ * numeric,reverseǡȤ̤ͥפƤ2֤
  */
 int mssChkSorted( struct mssFields *sf, struct mssHeader *hd)
 {
@@ -1252,11 +1255,23 @@ int mssChkSorted( struct mssFields *sf, struct mssHeader *hd)
   /*ƥȤξϥȤƤȤߤʤ*/
   if(mssGV.txtFlg) return(1);
 
-  /*-kѥ᡼ιֹ-ֹͥ*/
+  /*sfγƹܤhdγƹܤӤ*/
   for(i=0; i<sf->cnt; i++){
-    if(mssFldNum2SrtRev(hd->flds,(*(sf->fi+i))->num)   != (*(sf->fi+i))->revFlg) return(0);
-    if(mssFldNum2SrtNum(hd->flds,(*(sf->fi+i))->num)   != (*(sf->fi+i))->numFlg) return(0);
-    if(mssFldNum2SrtPri(hd->flds,(*(sf->fi+i))->num)-1 != i                 ) return(0);
+    if(mssFldNum2SrtRev(hd->flds,(*(sf->fi+i))->num) != (*(sf->fi+i))->revFlg){
+      return(0);
+    }
+    if(mssFldNum2SrtNum(hd->flds,(*(sf->fi+i))->num) != (*(sf->fi+i))->numFlg){
+      return(0);
+    }
+    if(mssFldNum2SrtPri(hd->flds,(*(sf->fi+i))->num)-1 != i ) {
+      return(0);
+    }
+  }
+
+  /*numeric,reverseꤵƤ뤫򸡺*/
+  for(i=0; i<sf->cnt; i++){
+    if( (*(sf->fi+i))->revFlg) return(2);
+    if( (*(sf->fi+i))->numFlg) return(2);
   }
   return(1);
 }
@@ -1302,7 +1317,7 @@ static int *setFldNo2optNo(struct mssFields *flds, int headFldCnt)
  * 1. newNam'&'ʸޤޤƤСʸnamִ롣
  * 2. 1ִ̿̾ĹMssFieldMaxLenĶȥ顼&
  * 3. newNamNULLʤСnam֤
- * 3. ̾Τ˿ʸΰݤΤǡnam,newNameȤδ
+ * 4. ̾Τ˿ʸΰݤΤǡnam,newNameȤδ
  *    Ϥʤ
  *   ex.) 
  *     newNam = NULL        , nam="Jan" -> return("Jan")
@@ -1336,6 +1351,7 @@ static char *setNewFldNam(char *newNam,char *nam)
             mssEnd(mssErrorNoDefault);
           }
         }
+        newNam++;
       }else{
         retStr[i++]=*newNam++;
         if(i>=MssFieldMaxLen-1){
@@ -1376,7 +1392,17 @@ static void evalOptFldNameGlob(MssOptFLD *optFLD, struct mssFields *flds)
   for(i=0 ; i<optFLD->cnt ; i++) { /*ץǻꤵ줿ƹ*/
     /*WC˥ޥåܥꥹȤfiList(ǸNULLǽ)*/
     fiCnt=0;
-    fiList = mssFldGlbNam2Add(flds,*(optFLD->nam+i));
+
+    /*globOKʤŸ*/
+    if(optFLD->globFlg) {
+      fiList = mssFldGlbNam2Add(flds,*(optFLD->nam+i));
+
+    /*globNGʤñ˹̾Address*/
+    }else{
+      fiList = mssCalloc(sizeof(struct mssFldInfo *) * 2,"evalGlob");
+      *fiList = mssFldNam2Add(flds,*(optFLD->nam+i));
+    }
+
     while( *(fiList+fiCnt) != NULL ){
 
       /*磻ɥŸ塢optFld->maxCntۤ饨顼Υå*/
@@ -1443,7 +1469,7 @@ void mssSetOptFld(MssOptFLD *optFLD, struct mssHeader *hd)
   optFLD->flds=mssInitFields();
 
   /*磻ɥɤɾ*/
-  if(optFLD->globFlg) evalOptFldNameGlob(optFLD, hd->flds);
+  evalOptFldNameGlob(optFLD, hd->flds);
 
   /*optFLDǻꤵ줿̾ΥإåܤؤΥݥ󥿤Ͽ*/
   for(i=0 ; i<optFLD->cnt ; i++) {
@@ -1469,9 +1495,10 @@ void mssSetOptFld(MssOptFLD *optFLD, struct mssHeader *hd)
 
 /**
  * # FUNCTION #
- * MssOptKEY¤Τιܤإåιܤͤ碌ưʲΣĤ򤪤ʤ
+ * MssOptKEY¤Τιܤإåιܤͤ碌ưʲ3ĤΤȤ򤪤ʤ
  * 1.optFLD->fldsˡإåбܾ򥳥ԡ롣
  * 2.إåιֹ->ץλ֤ꡣ
+ * 3.ƱܤʣꤷƤХ顼ǽλ
  *   ex.) -f customer,date
  *             optFLD->nam   ={"customer","date"}
  *        ϥǡΥإå={"customer","class","date","time","amt1","amt2"}
@@ -1483,13 +1510,24 @@ void mssSetOptFld(MssOptFLD *optFLD, struct mssHeader *hd)
  */
 void mssSetOptKey(MssOptKEY *optKEY, struct mssHeader *hd)
 {
-  int i;
+  int i,j;
 
   optKEY->flds=mssInitFields();
 
-  /*optFLDǻꤵ줿̾ΥإåܤؤΥݥ󥿤Ͽ*/
+  /*optKEYǻꤵ줿̾ΥإåܤؤΥݥ󥿤Ͽ*/
   for(i=0 ; i<optKEY->cnt ; i++) {
     mssAddFieldsByFldInfo(optKEY->flds, mssFldNam2Add(hd->flds,*(optKEY->nam+i)));
+    mssSetFldInfoSort(*(optKEY->flds->fi+i),0,0,0);
+  }
+
+  /*optKEYƱܤꤵ줿饨顼*/
+  for(i=0 ; i<optKEY->cnt-1 ; i++) {
+    for(j=i+1 ; j<optKEY->cnt ; j++) {
+      if( MssFlds2num(optKEY->flds,i)==MssFlds2num(optKEY->flds,j) ){
+        mssShowErrMsg("can not specify a same field in key field(s)");
+        mssEnd(mssErrorNoDefault);
+      }
+    }
   }
 
   /*ֹflag*/
