@@ -112,15 +112,25 @@ char *mssNencoding(char *str, int len, iconv_t *icid)
  * ̾(element)Ͽ(ݤ)
  * icidåȤƤ(NULLǤʤ)󥳡ǥ󥰤Ѵ򤪤ʤ
  * °򥻥åȤmssAddXmlTagAttribute{Str,Int,Dbl}Ѥ롣
+ * elementNULLλNULL֤
+ * element'\0'ξϥ顼λ
  */
 struct mssXmlTag *mssInitXmlTag(char *element, iconv_t *icid)
 {
   struct mssXmlTag *xmlTag;
-  xmlTag=mssCalloc(sizeof(struct mssXmlTag),"initXmlTag");
-  if(icid==NULL){
-    xmlTag->element=mssStrdup(element);
+
+  if(element==NULL){
+    xmlTag=NULL;
+  }else if(*element=='\0'){
+    mssShowErrMsg("name of XML element is NULL");
+    exit(mssErrorNoDefault);
   }else{
-    xmlTag->element=mssEncoding(element,icid);
+    xmlTag=mssCalloc(sizeof(struct mssXmlTag),"initXmlTag");
+    if(icid==NULL){
+      xmlTag->element=mssStrdup(element);
+    }else{
+      xmlTag->element=mssEncoding(element,icid);
+    }
   }
   return(xmlTag);
 }
@@ -130,7 +140,7 @@ struct mssXmlTag *mssInitXmlTag(char *element, iconv_t *icid)
  * ѥ᡼Ϳ줿ǡ°ꥹȤ򥻥åȡmssXmlTag¤Τ֤
  * str="element:attNam1=attVal1,attNam2=attVal2"
  * icidåȤƤ(NULLǤʤ)󥳡ǥ󥰤Ѵ򤪤ʤ
- * strNULLξNULL֤
+ * ̾'\0'ξϥ顼λ
  */
 struct mssXmlTag *mssInitXmlTagByOpt(char *str, iconv_t *icid)
 {
@@ -195,9 +205,10 @@ void mssFreeXmlTag(struct mssXmlTag *xmlTag)
 /**
  * # FUNCTION #
  * mssXmlTag¤Τ˻°̾(name)뤫ɤĴ١С
- * °̾Τ(ʸ:value)򹹿롣ʤС°̾ͤɲä
+ * °̾Ф(ʸ:value)򹹿롣ʤС°̾ͤɲä
  * icidåȤƤ(NULLǤʤ)󥳡ǥ󥰤Ѵ򤪤ʤ
  * xmlTag->attributesζǤ°̾򡢴Ǥͤݻ롣
+ * xmlTagNULLξϲ⤻˥꥿󤹤롣
  */
 void mssAddXmlTagAttributeStr(struct mssXmlTag *xmlTag, char *name, char *value, iconv_t *icid)
 {
@@ -205,7 +216,12 @@ void mssAddXmlTagAttributeStr(struct mssXmlTag *xmlTag, char *name, char *value,
   char *val;
   char *nam;
   int i;
-  if(xmlTag==NULL || name==NULL || value==NULL){
+
+  if(xmlTag==NULL){
+    return;
+  }
+
+  if(name==NULL || value==NULL){
     mssShowErrMsg("internal error in addXmlAttribute");
     exit(mssErrorNoDefault);
   }
@@ -252,6 +268,7 @@ void mssAddXmlTagAttributeStr(struct mssXmlTag *xmlTag, char *name, char *value,
  * °̾Τ(:value)򹹿롣ʤС°̾ͤɲä
  * icidåȤƤ(NULLǤʤ)󥳡ǥ󥰤Ѵ򤪤ʤ
  * xmlTag->attributesζǤ°̾򡢴Ǥͤݻ롣
+ * xmlTagNULLξϲ⤻˥꥿󤹤롣
  */
 void mssAddXmlTagAttributeInt(struct mssXmlTag *xmlTag, char *name, int value, iconv_t *icid)
 {
@@ -260,7 +277,12 @@ void mssAddXmlTagAttributeInt(struct mssXmlTag *xmlTag, char *name, int value, i
   char *val;
   char *nam;
   int i;
-  if(xmlTag==NULL || name==NULL){
+
+  if(xmlTag==NULL){
+    return;
+  }
+
+  if(name==NULL){
     mssShowErrMsg("internal error in addXmlAttribute");
     exit(mssErrorNoDefault);
   }
@@ -307,6 +329,7 @@ void mssAddXmlTagAttributeInt(struct mssXmlTag *xmlTag, char *name, int value, i
  * °̾Τ(¿:value)򹹿롣ʤС°̾ͤɲä
  * icidåȤƤ(NULLǤʤ)󥳡ǥ󥰤Ѵ򤪤ʤ
  * xmlTag->attributesζǤ°̾򡢴Ǥͤݻ롣
+ * xmlTagNULLξϲ⤻˥꥿󤹤롣
  */
 void mssAddXmlTagAttributeDbl(struct mssXmlTag *xmlTag, char *name, double value, iconv_t *icid)
 {
@@ -315,7 +338,12 @@ void mssAddXmlTagAttributeDbl(struct mssXmlTag *xmlTag, char *name, double value
   char *val;
   char *nam;
   int i;
-  if(xmlTag==NULL || name==NULL){
+
+  if(xmlTag==NULL){
+    return;
+  }
+
+  if(name==NULL){
     mssShowErrMsg("internal error in addXmlAttribute");
     exit(mssErrorNoDefault);
   }
